@@ -372,8 +372,8 @@ class NeuralNetwork():
         print("    Energy RMSE   {:8.6f}".format(E_mse))
 
         # Plotting the energy results.
-        energy_str = 'Energy: r2({:.4f}), MAE({:.4f} {}/atom)'. \
-                     format(E_r2, E_mae, self.unit)
+        energy_str = 'Energy: r2({:.4f}), MAE({:.4f} {}/atom), {:d} data'. \
+                     format(E_r2, E_mae, self.unit, len(energy))
         plt.title(energy_str)
         plt.scatter(energy, _energy, label='Energy', s=5)
         plt.legend(loc=2)
@@ -399,8 +399,8 @@ class NeuralNetwork():
             length = 'A'
             if self.unit == 'Ha':
                 length == 'Bohr'
-            force_str = 'Force: r2({:.4f}), MAE({:.3f} {}/{})'. \
-                        format(F_r2, F_mae, self.unit, length)
+            force_str = 'Force: r2({:.4f}), MAE({:.3f} {}/{}), {:d} data'. \
+                        format(F_r2, F_mae, self.unit, length, len(force))
             plt.title(force_str)
             plt.scatter(force, _force, s=5, label='Force')
             plt.legend(loc=2)
@@ -425,8 +425,8 @@ class NeuralNetwork():
             print("    Stress RMSE    {:8.6f}".format(S_mse))
 
             # Plotting the stress results.
-            stress_str = 'Stress: r2({:.4f}), MAE({:.3f} GPa)'. \
-                        format(S_r2, S_mae)
+            stress_str = 'Stress: r2({:.4f}), MAE({:.3f} GPa), {:d} data'. \
+                        format(S_r2, S_mae, len(stress))
             plt.title(stress_str)
             plt.scatter(stress, _stress, s=5, label='Stress')
             plt.legend(loc=2)
@@ -616,31 +616,32 @@ class NeuralNetwork():
             scale = (1 - 0) / (_drange[:, 1] - _drange[:, 0])
 
             e = np.where(np.array(descriptor['elements'])==element)[0]
-            ee0 = np.where(descriptor['seq'][:,0]==e[0])[0][0]
-            ee1 = np.where(descriptor['seq'][:,0]==e[-1])[0][-1]
+            if len(e) > 0:
+                ee0 = np.where(descriptor['seq'][:,0]==e[0])[0][0]
+                ee1 = np.where(descriptor['seq'][:,0]==e[-1])[0][-1]
 
-            i_size = list(descriptor['elements']).count(element) #number of atoms in type i
-            m_size = ee1-ee0+1# number of pairs
+                i_size = list(descriptor['elements']).count(element) #number of atoms in type i
+                m_size = ee1-ee0+1# number of pairs
 
-            d['x'][element] = torch.zeros([i_size, no_of_descriptors])
-            d['dxdr'][element] = torch.zeros([m_size, no_of_descriptors, 3], dtype=torch.float64) ####
-            d['rdxdr'][element] = torch.zeros([i_size, no_of_descriptors, 6])
+                d['x'][element] = torch.zeros([i_size, no_of_descriptors])
+                d['dxdr'][element] = torch.zeros([m_size, no_of_descriptors, 3], dtype=torch.float64) ####
+                d['rdxdr'][element] = torch.zeros([i_size, no_of_descriptors, 6])
 
-            if e.size > 0:
-                des = 0 + np.einsum('j,ij->ij', scale, (descriptor['x'][e[0]:e[-1]+1] - np.expand_dims(_drange[:, 0], 0)))
-                desp = np.einsum('j,ijk->ijk', scale, descriptor['dxdr'][ee0:ee1+1])
-                dess = np.einsum('j,ijk->ijk', scale, descriptor['rdxdr'][e[0]:e[-1]+1])
-                
-                d['x'][element] += torch.from_numpy(des)
-                d['seq'][element] = deepcopy(descriptor['seq'][ee0:ee1+1])
+                if e.size > 0:
+                    des = 0 + np.einsum('j,ij->ij', scale, (descriptor['x'][e[0]:e[-1]+1] - np.expand_dims(_drange[:, 0], 0)))
+                    desp = np.einsum('j,ijk->ijk', scale, descriptor['dxdr'][ee0:ee1+1])
+                    dess = np.einsum('j,ijk->ijk', scale, descriptor['rdxdr'][e[0]:e[-1]+1])
+                    
+                    d['x'][element] += torch.from_numpy(des)
+                    d['seq'][element] = deepcopy(descriptor['seq'][ee0:ee1+1])
 
-                if self.unit == 'eV':  
-                    d['dxdr'][element] += torch.from_numpy(desp)
-                    d['rdxdr'][element] += torch.from_numpy(dess)
-                else:
-                    d['dxdr'][element] += torch.from_numpy(0.529177 * desp)
-                    d['rdxdr'][element] += torch.from_numpy(0.529177**3*desp)
-            d['seq'][element][:, 0] -= min(d['seq'][element][:, 0]) #adjust the initial position
+                    if self.unit == 'eV':  
+                        d['dxdr'][element] += torch.from_numpy(desp)
+                        d['rdxdr'][element] += torch.from_numpy(dess)
+                    else:
+                        d['dxdr'][element] += torch.from_numpy(0.529177 * desp)
+                        d['rdxdr'][element] += torch.from_numpy(0.529177**3*desp)
+                d['seq'][element][:, 0] -= min(d['seq'][element][:, 0]) #adjust the initial position
 
         x = d['x']
         if bforce:
